==> qtjambi-qt3dcore-5.15.6-sources.jar: io/qt/qt3d/core/QNodeCommand.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all CommandRequested QSceneChange events</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html">Qt3DCore::QNodeCommand</a></p>
 */
public class QNodeCommand extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#QNodeCommand">Qt3DCore::QNodeCommand::QNodeCommand(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QNodeCommand(io.qt.qt3d.core.QNodeId id){
        super((QPrivateConstructor)null);
        initialize_native(this, id);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeCommand instance, io.qt.qt3d.core.QNodeId id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#commandId">Qt3DCore::QNodeCommand::commandId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int commandId(){
        return commandId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int commandId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#data">Qt3DCore::QNodeCommand::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#inReplyTo">Qt3DCore::QNodeCommand::inReplyTo()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int inReplyTo(){
        return inReplyTo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int inReplyTo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#name">Qt3DCore::QNodeCommand::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setData">Qt3DCore::QNodeCommand::setData(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.Object data){
        setData_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QVariant(long __this__nativeId, java.lang.Object data);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setName">Qt3DCore::QNodeCommand::setName(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setName(java.lang.String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setReplyToCommandId">Qt3DCore::QNodeCommand::setReplyToCommandId(Qt3DCore::QNodeCommand::CommandId)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setReplyToCommandId(int id){
        setReplyToCommandId_native_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    @io.qt.QtUninvokable
    private native void setReplyToCommandId_native_unsigned_int(long __this__nativeId, int id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeCommand(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QNodeCommand.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all CommandRequested QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html">Qt3DCore::QNodeCommand</a></p>
 */
public class QNodeCommand extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#QNodeCommand">Qt3DCore::QNodeCommand::QNodeCommand(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QNodeCommand(io.qt.qt3d.core.QNodeId id){
        super((QPrivateConstructor)null);
        initialize_native(this, id);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeCommand instance, io.qt.qt3d.core.QNodeId id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#commandId">Qt3DCore::QNodeCommand::commandId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int commandId(){
        return commandId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int commandId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#data">Qt3DCore::QNodeCommand::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#inReplyTo">Qt3DCore::QNodeCommand::inReplyTo()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int inReplyTo(){
        return inReplyTo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int inReplyTo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#name">Qt3DCore::QNodeCommand::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setData">Qt3DCore::QNodeCommand::setData(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.Object data){
        setData_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QVariant(long __this__nativeId, java.lang.Object data);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setName">Qt3DCore::QNodeCommand::setName(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setName(java.lang.String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setReplyToCommandId">Qt3DCore::QNodeCommand::setReplyToCommandId(Qt3DCore::QNodeCommand::CommandId)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setReplyToCommandId(int id){
        setReplyToCommandId_native_unsigned_int(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    @io.qt.QtUninvokable
    private native void setReplyToCommandId_native_unsigned_int(long __this__nativeId, int id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeCommand(QPrivateConstructor p) { super(p); } 
    
}
